/**
* DO NOT EDIT THIS FILE.
* See the following change record for more information,
* https://www.drupal.org/node/2815083
* @preserve
**/

(function ($, Drupal, drupalSettings) {
  function hide($placeholder) {
    return $placeholder.closest('.knowledge-new-knowledge').prev().addClass('last').end().hide();
  }

  function remove($placeholder) {
    hide($placeholder).remove();
  }

  function show($placeholder) {
    return $placeholder.closest('.knowledge-new-knowledge').prev().removeClass('last').end().show();
  }

  function processNodeNewKnowledgeLinks(placeholders) {
    var $placeholdersToUpdate = {};
    var fieldName = 'knowledge';
    var $placeholder;
    placeholders.forEach(function (placeholder) {
      $placeholder = $(placeholder);
      var timestamp = parseInt($placeholder.attr('data-history-node-last-knowledge-timestamp'), 10);
      fieldName = $placeholder.attr('data-history-node-field-name');
      var nodeID = $placeholder.closest('[data-history-node-id]').attr('data-history-node-id');
      var lastViewTimestamp = Drupal.history.getLastRead(nodeID);

      if (timestamp > lastViewTimestamp) {
        $placeholdersToUpdate[nodeID] = $placeholder;
      } else {
        remove($placeholder);
      }
    });
    var nodeIDs = Object.keys($placeholdersToUpdate);

    if (nodeIDs.length === 0) {
      return;
    }

    function render(results) {
      Object.keys(results || {}).forEach(function (nodeID) {
        if ($placeholdersToUpdate.hasOwnProperty(nodeID)) {
          var $placeholderItem = $placeholdersToUpdate[nodeID];
          var result = results[nodeID];
          $placeholderItem[0].textContent = Drupal.formatPlural(result.new_total_count, '1 new knowledge', '@count new knowledge');
          $placeholderItem.attr('href', result.first_new_knowledge_link).removeClass('hidden');
          show($placeholderItem);
        }
      });
    }

    if (drupalSettings.knowledge && drupalSettings.knowledge.newKnowledgeLinks) {
      render(drupalSettings.knowledge.newKnowledgeLinks.node[fieldName]);
    } else {
      $.ajax({
        url: Drupal.url('knowledge/render_new_knowledge_node_links'),
        type: 'POST',
        data: {
          'node_ids[]': nodeIDs,
          field_name: fieldName
        },
        dataType: 'json',
        success: render
      });
    }
  }

  Drupal.behaviors.nodeNewKnowledgeLink = {
    attach: function attach(context) {
      var nodeIDs = [];
      var placeholders = once('history', '[data-history-node-last-knowledge-timestamp]', context).filter(function (placeholder) {
        var $placeholder = $(placeholder);
        var lastKnowledgeTimestamp = parseInt($placeholder.attr('data-history-node-last-knowledge-timestamp'), 10);
        var nodeID = $placeholder.closest('[data-history-node-id]').attr('data-history-node-id');

        if (Drupal.history.needsServerCheck(nodeID, lastKnowledgeTimestamp)) {
          nodeIDs.push(nodeID);
          hide($placeholder);
          return true;
        }

        remove($placeholder);
        return false;
      });

      if (placeholders.length === 0) {
        return;
      }

      Drupal.history.fetchTimestamps(nodeIDs, function () {
        processNodeNewKnowledgeLinks(placeholders);
      });
    }
  };
})(jQuery, Drupal, drupalSettings);