<?php

namespace Drupal\knowledge\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Settings for the KnowledgeCompetency entity.
 *
 * @ingroup knowledge
 */
class KnowledgeCompetencySettingsForm extends FormBase {

  /**
   * The user role storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $roleStorage;

  /**
   * The knowledge settings config.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Instantiates this form class.
    $instance = parent::create($container);
    $instance->roleStorage = $container->get('entity_type.manager')->getStorage('user_role');
    $instance->config = $container->get('config.factory')->getEditable('knowledge.settings');
    return $instance;
  }

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId() {
    return 'knowledge_competency_settings';
  }

  /**
   * Form submission handler.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Empty implementation of the abstract submit class.
    $this->config
      ->set('competency.candidate', $form_state->getValue('candidate'))
      ->set('competency.contributor', $form_state->getValue('contributor'))
      ->set('competency.publisher', $form_state->getValue('publisher'))
      ->set('competency.all', $form_state->getValue('all'))
      ->save();
  }

  /**
   * Defines the settings form for Competency entities.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   Form definition array.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $candidate = $this->roleStorage->load('knowledge_candidate');
    $contributor = $this->roleStorage->load('knowledge_contributor');
    $publisher = $this->roleStorage->load('knowledge_publisher');
    $options = [
      '_none' => $this->t('Do nothing'),
      'contributor' => $this->t('Promote to @contributor', [
        '@contributor' => $contributor->label(),
      ]),
      'publisher' => $this->t('Promote to @publisher', [
        '@publisher' => $publisher->label(),
      ]),
    ];
    $form['candidate'] = [
      '#title' => $candidate->label(),
      '#type' => 'select',
      '#options' => $options,
      '#default_value' => $this->config->get('competency.candidate'),
    ];
    $form['contributor'] = [
      '#title' => $contributor->label(),
      '#type' => 'select',
      '#options' => $options,
      '#default_value' => $this->config->get('competency.contributor'),
    ];

    $form['publisher'] = [
      '#title' => $publisher->label(),
      '#type' => 'select',
      '#options' => $options,
      '#default_value' => $this->config->get('competency.publisher'),
    ];

    $form['all'] = [
      '#title' => $this->t('All'),
      '#type' => 'select',
      '#options' => $options,
      '#default_value' => $this->config->get('competency.all'),
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#button_type' => 'primary',
      '#submit' => ['::submitForm'],
    ];

    return $form;
  }

}
