<?php

namespace Drupal\knowledge;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Access controller for the Competency entity.
 *
 * @see \Drupal\knowledge\Entity\KnowledgeCompetency.
 */
class KnowledgeCompetencyAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    /** @var \Drupal\knowledge\Entity\KnowledgeCompetencyInterface $entity */

    switch ($operation) {

      case 'view':

        if (!$entity->isPublished()) {
          return AccessResult::allowedIfHasPermission($account, 'view unpublished competency entities');
        }

        return AccessResult::allowedIfHasPermission($account, 'view published competency entities');

      case 'update':

        return AccessResult::allowedIfHasPermission($account, 'edit competency entities');

      case 'delete':

        return AccessResult::allowedIfHasPermission($account, 'delete competency entities');
    }

    // Unknown operation, no opinion.
    return AccessResult::neutral();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'add competency entities');
  }

}
