<?php

namespace Drupal\Tests\knowledge\Functional;

use Drupal\knowledge\Entity\Knowledge;
use Drupal\knowledge\KnowledgeInterface;
use Drupal\knowledge\Tests\KnowledgeTestTrait;
use Drupal\node\Entity\Node;
use Drupal\Tests\BrowserTestBase;

/**
 * Tests visibility of knowledge on book pages.
 *
 * @group knowledge
 */
class KnowledgeBookTest extends BrowserTestBase {

  use KnowledgeTestTrait;

  /**
   * Modules to install.
   *
   * @var array
   */
  protected static $modules = ['book', 'knowledge'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // Create knowledge field on book.
    $this->addDefaultKnowledgeField('node', 'book');
  }

  /**
   * Tests knowledge in book export.
   */
  public function testBookKnowledgePrint() {
    $book_node = Node::create([
      'type' => 'book',
      'title' => 'Book title',
      'body' => 'Book body',
    ]);
    $book_node->book['bid'] = 'new';
    $book_node->save();

    $knowledge = Knowledge::create([
      'entity_id' => $book_node->id(),
      'entity_type' => 'node',
      'field_name' => 'knowledge',
      'status' => KnowledgeInterface::PUBLISHED,
    ]);
    $knowledge->save();

    $knowledge_user = $this->drupalCreateUser([
      'access printer-friendly version',
      'access knowledge',
      'post knowledge',
    ]);
    $this->drupalLogin($knowledge_user);

    $this->drupalGet('node/' . $book_node->id());

    $this->assertSession()->pageTextContains('Add new knowledge');
    // Ensure that the knowledge form subject field exists.
    $this->assertSession()->fieldExists('subject[0][value]');

    $this->drupalGet('book/export/html/' . $book_node->id());

    $this->assertSession()->pageTextContains('Knowledge');

    $this->assertSession()->pageTextNotContains('Add new knowledge');
    // Verify that the knowledge form subject field is not found.
    $this->assertSession()->fieldNotExists('subject[0][value]');
  }

}
