<?php

namespace Drupal\Tests\knowledge\Functional;

use Drupal\knowledge\Tests\KnowledgeTestTrait;
use Drupal\node\Entity\NodeType;
use Drupal\Tests\BrowserTestBase;

/**
 * Tests knowledge status field access.
 *
 * @group knowledge
 */
class KnowledgeStatusFieldAccessTest extends BrowserTestBase {

  use KnowledgeTestTrait;

  /**
   * {@inheritdoc}
   */
  public $profile = 'testing';

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Knowledge admin.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $knowledgeAdmin;

  /**
   * Node author.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $nodeAuthor;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node',
    'knowledge',
    'user',
    'system',
    'text',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $node_type = NodeType::create([
      'type' => 'article',
      'name' => 'Article',
    ]);
    $node_type->save();
    $this->nodeAuthor = $this->drupalCreateUser([
      'create article content',
      'skip knowledge approval',
      'post knowledge',
      'edit own knowledge',
      'access knowledge',
      'administer nodes',
    ]);
    $this->knowledgeAdmin = $this->drupalCreateUser([
      'administer knowledge',
      'create article content',
      'edit own knowledge',
      'skip knowledge approval',
      'post knowledge',
      'access knowledge',
      'administer nodes',
    ]);
    $this->addDefaultKnowledgeField('node', 'article');
  }

  /**
   * Tests knowledge status field access.
   */
  public function testKnowledgeStatusFieldAccessStatus() {
    $this->drupalLogin($this->nodeAuthor);
    $this->drupalGet('node/add/article');
    $assert = $this->assertSession();
    $assert->fieldNotExists('knowledge[0][status]');
    $this->submitForm(['title[0][value]' => 'Node 1'], 'Save');
    $assert->fieldExists('subject[0][value]');
    $this->drupalLogin($this->knowledgeAdmin);
    $this->drupalGet('node/add/article');
    $assert->fieldExists('knowledge[0][status]');
    $this->submitForm(['title[0][value]' => 'Node 2'], 'Save');
    $assert->fieldExists('subject[0][value]');
  }

}
